@@ -82,11 +82,7 @@ NULL
 #' # to the handler
 #' with_handlers(cnd_signal(cnd), foo = function(c) "caught!")
 #' tryCatch(cnd_signal(cnd), foo = function(c) "caught!")
-cnd <- function(class,
-                ...,
-                message = "",
-                call = NULL,
-                use_cli_format = NULL) {
+cnd <- function(class, ..., message = "", call = NULL, use_cli_format = NULL) {
   check_required(class)
 
   if (is_environment(call)) {
@@ -106,13 +102,15 @@ cnd <- function(class,
 
 #' @rdname cnd
 #' @export
-error_cnd <- function(class = NULL,
-                      ...,
-                      message = "",
-                      call = NULL,
-                      trace = NULL,
-                      parent = NULL,
-                      use_cli_format = NULL) {
+error_cnd <- function(
+  class = NULL,
+  ...,
+  message = "",
+  call = NULL,
+  trace = NULL,
+  parent = NULL,
+  use_cli_format = NULL
+) {
   if (!is_null(trace) && !inherits(trace, "rlang_trace")) {
     stop_input_type(trace, "`NULL` or an rlang backtrace")
   }
@@ -139,13 +137,15 @@ error_cnd <- function(class = NULL,
     fields
   )
 }
-error_cnd_fields <- function(trace,
-                             parent,
-                             ...,
-                             use_cli_format = NULL,
-                             .subclass = NULL,
-                             `_env` = caller_env(),
-                             `_frame` = caller_env(2)) {
+error_cnd_fields <- function(
+  trace,
+  parent,
+  ...,
+  use_cli_format = NULL,
+  .subclass = NULL,
+  `_env` = caller_env(),
+  `_frame` = caller_env(2)
+) {
   if (!is_null(.subclass)) {
     deprecate_subclass(.subclass, "error_cnd", `_env`)
   }
@@ -161,11 +161,13 @@ error_cnd_fields <- function(trace,
 
 #' @rdname cnd
 #' @export
-warning_cnd <- function(class = NULL,
-                        ...,
-                        message = "",
-                        call = NULL,
-                        use_cli_format = NULL) {
+warning_cnd <- function(
+  class = NULL,
+  ...,
+  message = "",
+  call = NULL,
+  use_cli_format = NULL
+) {
   if (is_environment(call)) {
     call <- error_call(call)
   }
@@ -188,11 +190,13 @@ warning_cnd <- function(class = NULL,
 
 #' @rdname cnd
 #' @export
-message_cnd <- function(class = NULL,
-                        ...,
-                        message = "",
-                        call = NULL,
-                        use_cli_format = NULL) {
+message_cnd <- function(
+  class = NULL,
+  ...,
+  message = "",
+  call = NULL,
+  use_cli_format = NULL
+) {
   if (is_environment(call)) {
     call <- error_call(call)
   }
@@ -213,12 +217,14 @@ message_cnd <- function(class = NULL,
   )
 }
 
-cnd_fields <- function(...,
-                       .subclass = NULL,
-                       `_use_cli_format` = NULL,
-                       `_fn` = "cnd",
-                       `_env` = caller_env(),
-                       `_frame` = caller_env(2)) {
+cnd_fields <- function(
+  ...,
+  .subclass = NULL,
+  `_use_cli_format` = NULL,
+  `_fn` = "cnd",
+  `_env` = caller_env(),
+  `_frame` = caller_env(2)
+) {
   if (!is_null(.subclass)) {
     deprecate_subclass(.subclass, `_fn`, `_env`)
   }
@@ -287,6 +293,9 @@ cnd_type <- function(cnd) {
 #' object is a particular kind of error or has been caused by such an
 #' error.
 #'
+#' Some chained conditions carry parents that are not inherited. See
+#' the `.inherit` argument of [abort()], [warn()], and [inform()].
+#'
 #'
 #' # Capture an error with `cnd_inherits()`
 #'
@@ -345,6 +354,19 @@ cnd_type <- function(cnd) {
 #' class(cnd$parent)
 #' ```
 #'
+#' Note that `try_fetch()` uses `cnd_inherits()` internally. This
+#' makes it very easy to match a parent condition:
+#'
+#' ```{r, comment = "#>", collapse = TRUE}
+#' cnd <- try_fetch(
+#'   f(),
+#'   bar = function(x) x
+#' )
+#'
+#' # This is the parent
+#' class(cnd)
+#' ```
+#'
 #' @param cnd A condition to test.
 #' @param class A class passed to [inherits()].
 #'
@@ -359,6 +381,11 @@ cnd_some <- function(cnd, fn, ...) {
       return(TRUE)
     }
 
+    inherit <- .subset2(.subset2(cnd, "rlang"), "inherit")
+    if (is_false(inherit)) {
+      return(FALSE)
+    }
+
     cnd <- cnd[["parent"]]
   }
 
@@ -379,11 +406,13 @@ is_rlang_error <- function(x) {
 }
 
 #' @export
-format.rlang_error <- function(x,
-                               ...,
-                               backtrace = TRUE,
-                               simplify = NULL,
-                               drop = NULL) {
+format.rlang_error <- function(
+  x,
+  ...,
+  backtrace = TRUE,
+  simplify = NULL,
+  drop = NULL
+) {
   simplify <- arg_match_simplify(simplify)
   drop <- arg_match_drop(drop)
 
@@ -406,7 +435,7 @@ format.rlang_error <- function(x,
   # Recommend printing the full backtrace if called from `last_error()`
   from_last_error <- is_true(x$rlang$internal$from_last_error)
   if (from_last_error && !is_null(x$trace)) {
-    if (use_tree_display() && drop && !all(x$trace$visible)) {
+    if (drop && !all(x$trace$visible)) {
       n_hidden <- sum(!x$trace$visible)
       hidden <- ngettext(
         n_hidden,
@@ -416,12 +445,16 @@ format.rlang_error <- function(x,
       hidden <- sprintf(hidden, n_hidden)
 
       last_trace <- style_rlang_run("last_trace(drop = FALSE)")
-      reminder <- silver(sprintf("Run %s to see %s.", last_trace, hidden))
+      reminder <- col_silver(sprintf("Run %s to see %s.", last_trace, hidden))
 
       out <- paste_line(out, reminder)
     } else if (simplify == "branch") {
       last_trace <- style_rlang_run("last_trace()")
-      reminder <- silver(paste0("Run `", last_trace, "` to see the full context."))
+      reminder <- col_silver(paste0(
+        "Run `",
+        last_trace,
+        "` to see the full context."
+      ))
       out <- paste_line(out, reminder)
     }
   }
@@ -445,10 +478,7 @@ summary.rlang_warning <- function(object, ...) {
   print(object, ..., simplify = "none")
 }
 #' @export
-format.rlang_warning <- function(x,
-                                 ...,
-                                 backtrace = TRUE,
-                                 simplify = c("branch", "none")) {
+format.rlang_warning <- function(x, ..., backtrace = TRUE, simplify = "none") {
   cnd_format(x, ..., backtrace = backtrace, simplify = simplify)
 }
 
@@ -463,13 +493,15 @@ cnd_print <- function(x, ...) {
   writeLines(cnd_format(x, ...))
   invisible(x)
 }
-cnd_format <- function(x,
-                       ...,
-                       backtrace = TRUE,
-                       simplify = NULL,
-                       prefix = TRUE,
-                       alert = NULL,
-                       drop = NULL) {
+cnd_format <- function(
+  x,
+  ...,
+  backtrace = TRUE,
+  simplify = NULL,
+  prefix = TRUE,
+  alert = NULL,
+  drop = NULL
+) {
   simplify <- arg_match_simplify(simplify)
   drop <- arg_match_drop(drop)
 
@@ -542,7 +574,8 @@ cnd_format <- function(x,
   }
 
   is_same_trace <- function() {
-    compare <- if (is_null(pending_trace)) last_trace else pending_trace[["trace"]]
+    compare <- if (is_null(pending_trace)) last_trace else
+      pending_trace[["trace"]]
     if (!is_trace(trace) || !is_trace(compare)) {
       return(FALSE)
     }
@@ -584,7 +617,7 @@ paste_trace <- function(x, trace, simplify, ...) {
     ...,
     simplify = simplify
   )
-  paste_line(x, bold("Backtrace:"), trace_lines)
+  paste_line(x, style_bold("Backtrace:"), trace_lines)
 }
 
 cnd_type_header <- function(cnd) {
@@ -595,7 +628,7 @@ cnd_type_header <- function(cnd) {
     class <- c(type, class)
   }
 
-  bold(format_cls(class))
+  style_bold(format_cls(class))
 }
 
 testthat_print_cnd <- function(x, ...) {
