@@ -1,7 +1,9 @@
+// IWYU pragma: private; include "rlang.h"
+
 #ifndef RLANG_LANG_H
 #define RLANG_LANG_H
 
-#include "node.h"
+#include "rlang-types.h"
 
 
 #define r_new_call Rf_lcons
@@ -15,6 +17,7 @@ bool r_is_call(r_obj* x, const char* name);
 bool r_is_call_any(r_obj* x, const char** names, int n);
 
 r_obj* r_expr_protect(r_obj* x);
+r_obj* r_call_clone(r_obj* x);
 
 
 #endif
