@@ -29,7 +29,16 @@ test_that("can pluck promise value", {
   fn <- function(x) promise_value("x")
   expect_identical(fn(foo), sym("R_UnboundValue"))
 
-  fn <- function(x) { force(x); promise_value("x") }
+  fn <- function(x) {
+    force(x)
+    promise_value("x")
+  }
   foo <- "foo"
   expect_identical(fn(foo), "foo")
 })
+
+test_that("can take the address of the missing arg (#1521)", {
+  fn <- function(x) obj_address(x)
+  expect_true(is_string(fn()))
+  expect_true(is_string(obj_address(missing_arg())))
+})
