@@ -1,14 +1,15 @@
-context("parse")
-
 test_that("parse_quo() etc return quosures", {
-  expect_identical(parse_quo("foo(bar)", "base"), set_env(quo(foo(bar)), base_env()))
-  expect_identical(parse_quos("foo(bar)\n mtcars", "base"), new_quosures(list(set_env(quo(foo(bar)), base_env()), set_env(quo(mtcars), base_env()))))
-})
-
-test_that("parse_quosure() and parse_quosures() are deprecated", {
-  local_lifecycle_warnings()
-  expect_warning(parse_quosure("foo"), "deprecated")
-  expect_warning(parse_quosures("foo; bar"), "deprecated")
+  expect_identical(
+    parse_quo("foo(bar)", "base"),
+    set_env(quo(foo(bar)), base_env())
+  )
+  expect_identical(
+    parse_quos("foo(bar)\n mtcars", "base"),
+    new_quosures(list(
+      set_env(quo(foo(bar)), base_env()),
+      set_env(quo(mtcars), base_env())
+    ))
+  )
 })
 
 test_that("temporary connections are closed", {
@@ -21,8 +22,10 @@ test_that("temporary connections are closed", {
 })
 
 test_that("parse_expr() throws meaningful error messages", {
-  expect_error(parse_expr(""), "No expression to parse")
-  expect_error(parse_expr("foo; bar"), "More than one expression parsed")
+  expect_snapshot({
+    err(parse_expr(""))
+    err(parse_expr("foo; bar"))
+  })
 })
 
 test_that("parse_exprs() and parse_quos() handle character vectors", {
@@ -35,7 +38,10 @@ test_that("parse_exprs() and parse_quos() handle character vectors", {
 })
 
 test_that("parse_exprs() requires connections or character vectors", {
-  expect_error(parse_exprs(env()), "must be a character vector or an R connection")
+  expect_error(
+    parse_exprs(env()),
+    "must be a character vector or an R connection"
+  )
 })
 
 test_that("parse_exprs() and parse_quos() support empty input", {
@@ -45,14 +51,28 @@ test_that("parse_exprs() and parse_quos() support empty input", {
 
 test_that("parse_exprs() supports empty expressions (#954)", {
   x <- c("1", "", "2")
-  expect_equal(unstructure(parse_exprs(x)), list(1, 2))
-  expect_equal(unstructure(parse_exprs("")), list())
+  expect_equal(vec_unstructure(parse_exprs(x)), list(1, 2))
+  expect_equal(vec_unstructure(parse_exprs("")), list())
 })
 
 test_that("parse_exprs() preserves names (#808)", {
   x <- c(a = "1 + 2; 3", b = "", c = "4")
   expect_identical(
-    unstructure(parse_exprs(x)),
+    vec_unstructure(parse_exprs(x)),
     alist(a = 1 + 2, a = 3, c = 4)
   )
 })
+
+test_that("parse_expr() supports vectors of lines (#1540)", {
+  lines <- c("{", "  a", "  b", "}")
+  expect_equal(
+    parse_expr(lines),
+    quote({
+      a
+      b
+    })
+  )
+
+  lines <- c("a", "b")
+  expect_error(parse_expr(lines), "exactly 1 expression")
+})
